@@ -22,6 +22,7 @@ class ExampleGroup(runnable.Runnable):
             'after_all': []
         }
         self.helpers = {}
+        self._before_all_executed = False
 
     def __iter__(self):
         return iter(self.examples)
@@ -42,7 +43,7 @@ class ExampleGroup(runnable.Runnable):
 
             self.execute_hook('after_all', execution_context)
         except Exception:
-            self.failed()
+            self.fail()
 
         self._finish(reporter)
 
@@ -58,9 +59,14 @@ class ExampleGroup(runnable.Runnable):
 
     def _bind_helpers_to(self, execution_context):
         for name, method in self.helpers.items():
-            setattr(execution_context, name, partial(method, execution_context))
+            setattr(execution_context,
+                    name,
+                    partial(method, execution_context))
 
     def execute_hook(self, hook, execution_context):
+        if hook.endswith('_all') and not self.hooks.get(hook):
+            return
+
         if self.parent is not None:
             self.parent.execute_hook(hook, execution_context)
 
